@@ -117,8 +117,10 @@ class FastFourierTransformPlot(MplDrawer):
 
 if __name__ == "__main__":
 
-    def a():
-        """ """
+    def a() -> None:
+        """
+        :rtype: None
+        """
         duration_sec = 4
         mul = 1000
         sampling_Hz = 44
