@@ -20,8 +20,16 @@ def recursive_flatten_numpy(nested: Sequence) -> numpy.ndarray:
 
 
 class MyNdArray(numpy.ndarray):
+    """
+    Small extension
+    """
+
     @property
     def conjugate_transpose(self):
+        """
+
+        :return:
+        """
         return self.conj().T
 
 
