@@ -8,17 +8,24 @@ __doc__ = r"""
            """
 
 from typing import Sequence, Tuple, Union
+from enum import Enum
 
 import cv2
 import numpy
 from PIL import Image
 
-from draugr.opencv_utilities.bounding_boxes.colors import compute_color_for_labels
-from draugr.python_utilities.colors import RGB
+from draugr.python_utilities.colors import RGB, compute_color_for_labels
 
 __all__ = ["find_contours", "draw_masks"]
 
 
+class LineTypesEnum(Enum):
+    filled = cv2.FILLED
+    line4 = cv2.LINE_4  # 4-connected line
+    line8 = cv2.LINE_8  # 8-connected line
+    anti_aliased = cv2.LINE_AA  # antialiased line
+
+
 def find_contours(*args, **kwargs) -> Tuple:
     """
     Wraps cv2.findContours to maintain compatibility between versions 3 and 4
@@ -36,12 +43,14 @@ def find_contours(*args, **kwargs) -> Tuple:
 def draw_masks(
     image: Union[Image.Image, numpy.ndarray],
     masks: Union[Image.Image, numpy.ndarray],
+    *,
     labels: Sequence = None,
     border: bool = True,
-    border_width: float = 2,
+    border_width: int = 1,  # If it is negative, the contour interiors are drawn.
     border_color: Tuple = RGB(255, 255, 255),
     alpha: float = 0.5,
     color: Tuple = None,
+    line_type: LineTypesEnum = LineTypesEnum.anti_aliased
 ) -> numpy.ndarray:
     """
     Args:
@@ -55,20 +64,25 @@ def draw_masks(
     color: mask color
     Returns:
     numpy.ndarray"""
+
+    line_type = LineTypesEnum(line_type)
     if isinstance(image, Image.Image):
         image = numpy.array(image)
     assert isinstance(image, numpy.ndarray)
     if isinstance(masks, Image.Image):
         masks = numpy.array(masks)
     assert isinstance(masks, numpy.ndarray)
+    # TODO: ASSERT 3/4 CHANNELS!
+    if labels is None:
+        labels = list(range(masks.shape[0]))
     for i, mask in enumerate(masks):
         mask = mask.squeeze()[..., None].astype(numpy.bool)
 
-        label = labels[i] if labels is not None else 1
-        _color = compute_color_for_labels(label) if color is None else tuple(color)
+        label = labels[i]
+        mask_color = compute_color_for_labels(label) if color is None else tuple(color)
 
         image = numpy.where(
-            mask, mask * numpy.array(_color) * alpha + image * (1 - alpha), image
+            mask, mask * numpy.array(mask_color) * alpha + image * (1 - alpha), image
         )
         if border:
             contours, hierarchy = find_contours(
@@ -80,6 +94,10 @@ def draw_masks(
                 -1,
                 border_color,
                 thickness=border_width,
-                lineType=cv2.LINE_AA,
+                lineType=line_type.value,
             )
     return image.astype(numpy.uint8)
+
+
+if __name__ == "__main__":
+    pass
