@@ -21,7 +21,7 @@ def draw_axis(
     translation_vectors,
     camera_matrix,
     dist_coef,
-    size=1,
+    size: Number = 1,
 ):
     """
 
