@@ -37,8 +37,10 @@ def frame_generator(
 
 if __name__ == "__main__":
 
-    def asd():
-        """ """
+    def asd() -> None:
+        """
+        :rtype: None
+        """
         from tqdm import tqdm
 
         for image in tqdm(frame_generator(cv2.VideoCapture(0), None)):
