@@ -44,24 +44,30 @@ class TorchCacheSession(AlsoDecorator):
 
 if __name__ == "__main__":
 
-    def a():
-        """ """
+    def a() -> None:
+        """
+        :rtype: None
+        """
         print(torch.cuda.memory_cached(global_torch_device()))
         with TorchCacheSession():
             torch.tensor([0.0], device=global_torch_device())
             print(torch.cuda.memory_cached(global_torch_device()))
         print(torch.cuda.memory_cached(global_torch_device()))
 
-    def b():
-        """ """
+    def b() -> None:
+        """
+        :rtype: None
+        """
         model = torch.nn.Sequential(torch.nn.Linear(1, 1), torch.nn.Dropout(0.1))
         print(model.training)
         with TorchEvalSession(model):
             print(model.training)
         print(model.training)
 
-    def c():
-        """ """
+    def c() -> None:
+        """
+        :rtype: None
+        """
         model = torch.nn.Sequential(torch.nn.Linear(1, 1), torch.nn.Dropout(0.1))
         model.eval()
         print(model.training)
@@ -69,8 +75,10 @@ if __name__ == "__main__":
             print(model.training)
         print(model.training)
 
-    def d():
-        """ """
+    def d() -> None:
+        """
+        :rtype: None
+        """
         print(
             global_torch_device(override=global_torch_device(device_preference=False))
         )
@@ -79,8 +87,10 @@ if __name__ == "__main__":
             print(global_torch_device())
         print(global_torch_device())
 
-    def e():
-        """ """
+    def e() -> None:
+        """
+        :rtype: None
+        """
         print(global_torch_device(override=global_torch_device(device_preference=True)))
         print(global_torch_device())
         with TorchCpuSession():
