@@ -9,6 +9,8 @@ from pathlib import Path
 
 from tensorboard import program  # IMPORT OUT HERE; POSSIBLE RAISE CONDITIONS
 
+from draugr.python_utilities.sockets import is_port_in_use
+
 
 def launch_tensorboard(log_dir: Path, port: int = 6006) -> str:
     """
@@ -20,13 +22,7 @@ def launch_tensorboard(log_dir: Path, port: int = 6006) -> str:
     :return:
     :rtype:"""
 
-    def port_is_in_use(port_):
-        import socket
-
-        with socket.socket(socket.AF_INET, socket.SOCK_STREAM) as s:
-            return s.connect_ex(("localhost", port_)) == 0
-
-    if port_is_in_use(port):
+    if is_port_in_use(port):
         raise RuntimeError(f"Port {port} is in use")
 
     tb = program.TensorBoard()
