@@ -11,9 +11,6 @@ from pathlib import Path
 with open(Path(__file__).parent / "README.md", "r") as this_init_file:
     __doc__ += this_init_file.read()
 
-from .image_data import *
 from .matplotlib_utilities import *
-from .metric_overview_plot import *
 from .pillow_utilities import *
-from .signal_data import *
-from .figure_sessions import *
+from .seaborn_utilities import *
